@@ -1,10 +1,9 @@
 package List::Util::MaybeXS;
 use strict;
 use warnings;
-
 use Exporter (); BEGIN { *import = \&Exporter::import }
 
-our $VERSION = '1.50';
+our $VERSION = '1.500001';
 $VERSION =~ tr/_//d;
 
 our @EXPORT_OK;
@@ -22,7 +21,7 @@ BEGIN {
   my %need;
   @need{@EXPORT_OK} = ();
   local $@;
-  if (!$ENV{PERL_LIST_UTIL_MAYBEXS_NO_XS} && eval { require List::Util; 1 }) {
+  if (eval { require List::Util; 1 }) {
     my @import = grep defined &{"List::Util::$_"}, keys %need;
     if ( ! eval { List::Util->VERSION(1.45) } ) {
       @import = grep !/^uniq/, @import;
